@@ -454,7 +454,7 @@ class Stream():
         return (self.stream, stream_response)
 
     def lookback_window(self):
-        lookback_window = self.config.get('lookback_window', 0)
+        lookback_window = self.config.get('lookback_window') or '0'
         if not lookback_window.isdigit():
             raise TypeError("lookback_window '{}' is not numeric. Check your configuration".format(lookback_window))
         return int(lookback_window)
